[![License](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) [![Build Status](https://travis-ci.org/pmeier/pillow_affine.svg?branch=master)](https://travis-ci.org/pmeier/pillow_affine) [![codecov](https://codecov.io/gh/pmeier/pillow_affine/branch/master/graph/badge.svg)](https://codecov.io/gh/pmeier/pillow_affine) [![Documentation Status](https://readthedocs.org/projects/pillow-affine/badge/?version=latest)](https://pillow-affine.readthedocs.io/en/latest/?badge=latest)

# pillow_affine

`pillow_affine` provides affine transformation utilities for `Pillow`.

For installation instructions and usage examples please consult the documentation [hosted on readthedocs.com](https://pillow-affine.readthedocs.io/en/latest).